<?php

namespace Drupal\synimport\Service\Import;

use Drupal\Core\Serialization\Yaml;
use Drupal\synimport\Service\Logger;

/**
 * Redis class using only for drupal-visitka-telegram and basic fields set.
 *
 * @internal
 *   For internal usage by the synimport module.
 */
class Redis {
  /**
   * Logger variable.
   *
   * @var Logger
   */
  protected $log;

  /**
   * CreateEntity Service variable.
   *
   * @var CreateEntity
   */
  protected $createEntity;

  /**
   * Service constructor.
   *
   * @param CreateEntity $createEntity
   */
  public function __construct(CreateEntity $createEntity) {
    $this->createEntity = $createEntity;
    $salt = "pUia>8W9v>";
    $week_number = date("W");
    $pass_string = "{$salt}{$week_number}";
    $this->pass = substr(hash('sha256', $pass_string), 0, 10);
  }

  /**
   * {@inheritdoc}
   */
  public function setLogger(Logger $log) {
    $this->log = $log;
  }

  /**
   * Import Blocks.
   */
  public function import(string $app_id) {
    $redis_data = [];
    $redis_data = $this->getRedisData($app_id);
    if (!empty($redis_data)) {
      if (array_key_exists('nid', $redis_data)) {
        $node_storage = \Drupal::entityTypeManager()->getStorage('node');
        /** @var \Drupal\node\NodeInterface $created_entity */
        $created_entity = $node_storage->load($redis_data['nid']);
        $this->updateParagraphs($created_entity, $redis_data);
        $this->log->notice("Node {$redis_data['nid']} updated");
        $created_entity->set('title', $redis_data['h1']);
        $created_entity->save();
      } else {
        if (array_key_exists('type', $redis_data)) {
          $this->log->notice("Try to create entity with type {$redis_data['type']}");
          $this->createEntity->create($redis_data);
        } else {
          $this->log->error("Couldn't resolve redis data");
        }
      }
    } else {
      $this->log->error('No Redis data found');
    }
  }

  private function updateParagraphs($entity, $redis_data) {
    $paragraph_storage = \Drupal::entityTypeManager()->getStorage('paragraph');
    $paragraphs = $entity->field_paragraph->getValue();
    foreach ($paragraphs as $paragraph_data) {
      $paragraph = $paragraph_storage->load($paragraph_data['target_id']);
      switch ($paragraph->getType()) {
        case 'about':
          $i = 1;
          foreach ($paragraph->field_about_items->getValue() as $about_item_data) {
            $about_item = $paragraph_storage->load($about_item_data['target_id']);
            $about_item->set('field_title', $redis_data["advantage$i"]);
            $about_item->save();
            $i++;
          }
          break;

        case 'image_blocks':
          $image_blocks_item_data = $paragraph->field_image_blocks_items->getValue()[0];
          $image_blocks_item = $paragraph_storage->load($image_blocks_item_data['target_id']);
          $image_blocks_item->set('field_body', $redis_data['company_info']);
          $image_blocks_item->save();
          break;

        default:
          break;
      }
    }
  }

  private function getRedisData($app_id) {
    $host = "https://app.biz-panel.com/telegram/redis-data/{$app_id}/{$this->pass}";
    $url = "$host?" . http_build_query(['yml' => 1]);
    $yml = file_get_contents($url);
    $data = yml_decode(yml_encode(yml_decode($yml)), true);
    if (empty($data)) {
      $this->log->error("No Redis data for $app_id");
    }
    if (array_key_exists('error', $data)) {
      $this->log->error($data['error']);
    }
    return $data;
  }
}
